This product, ``eke.site``, provides display and RDF ingest of participating
sites that have joined the Early Detection Research Network (EDRN_).  Sites,
staff members, and investigators are integral parts of the EDRN Knowledge
Environment (EKE_).  EDRN uses the EKE to make it easy to discover, share,
search for, and retrieve all of EDRN's collective knowledge, including cancers
and other diseases, biomarkers, specimens, participants, studies, protocols,
and-as in the case of this product-sites and staff.

Although intended for the EDRN public portal, it can be installed in any
Plone_ compatible site.

This software is developed by the `EDRN Informatics Center`_  at JPL_,
operated by the California Institute of Technology, for NCI_.

.. References:
.. _EDRN Informatics Center: http://cancer.jpl.nasa.gov/
.. _EDRN: http://edrn.nci.nih.gov/
.. _EKE: http://cancer.jpl.nasa.gov/documents/applications/knowledge-environment
.. _JPL: http://www.jpl.nasa.gov/
.. _NCI: http://cancer.gov/
.. _Plone: http://plone.org/
